#
# spec file for package quazip-qt5
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define  so_ver 1
Name:           quazip-qt5
Version:        0.7.3
Release:        lp151.2.4
Summary:        C++ wrapper for ZIP/UNZIP
License:        GPL-2.0+ or LGPL-2.1+
Group:          Development/Libraries/C and C++
Url:            http://quazip.sourceforge.net/
Source0:        http://sourceforge.net/projects/quazip/files/quazip/%{version}/quazip-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  graphviz
BuildRequires:  graphviz-gnome
BuildRequires:  pkgconfig
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(Qt5Core)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
A C++ wrapper for the Gilles Vollant's ZIP/UNZIP C package, using Qt5 toolkit.
Useful to access ZIP archives from the Qt5 programs.

%package -n libquazip5-%{so_ver}
Summary:        C++ wrapper for ZIP/UNZIP
Group:          Development/Libraries/C and C++

%description -n libquazip5-%{so_ver}
A C++ wrapper for the Gilles Vollant's ZIP/UNZIP C package, using Qt5 toolkit.
Useful to access ZIP archives from the Qt5 programs.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       libquazip5-%{so_ver} = %{version}-%{release}
Requires:       pkgconfig(Qt5Core)
Provides:       libquazip-qt5-devel = %{version}
Obsoletes:      libquazip-qt5-devel < %{version}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package doc
Summary:        C++ wrapper for ZIP/UNZIP
Group:          Development/Libraries/C and C++
Provides:       libquazip-qt5-doc = %{version}
Obsoletes:      libquazip-qt5-doc < %{version}

%description doc
A C++ wrapper for the Gilles Vollant's ZIP/UNZIP C package, using Qt5 toolkit.
Useful to access ZIP archives from the Qt5 programs.

%prep
%setup -q -n quazip-%{version}

%build
%cmake -DCMAKE_CXX_FLAGS="-fPIC"
%make_jobs

cd ..
sed -i 's/HTML_TIMESTAMP\s*= YES/HTML_TIMESTAMP=NO/' Doxyfile
doxygen -u
doxygen

%install
cd build
%make_install
rm %{buildroot}/%{_libdir}/libquazip5.a

%post -n libquazip5-%{so_ver} -p /sbin/ldconfig
%postun -n libquazip5-%{so_ver} -p /sbin/ldconfig

%files -n libquazip5-%{so_ver}
%defattr(-,root,root,-)
%doc COPYING* NEWS.txt README.txt
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root,-)
%doc COPYING*
%{_includedir}/quazip5/
%{_libdir}/*.so
%{_datadir}/cmake/Modules/FindQuaZip5.cmake

%files doc
%defattr(-,root,root,-)
%doc doc/html

%changelog
* Tue May 30 2017 christophe@krop.fr
- Update to 0.7.3
  * Symlink handling.
  * Static linking exception for LGPL.
  * Minor bug fixes.
  * New JlCompress methods (QIODevice*-based API by Lukasz Kwiecinski)
  * Implemented QuaZioDevice::atEnd() and bytesAvailable(). these
    might break ABI, but pretty unlikely.
- Drop quazip-0.7.1-r260.diff. Merged upstream
* Tue Nov 10 2015 mlin@suse.com
- Add Provides/Obsoletes for old libquazip-qt5
* Wed Nov  4 2015 hpj@urpla.net
- streamline quazip and libquazip-qt5 specs
- rename libquazip-qt5.* to quazip-qt5.*
- apply quazip-0.7.1-r260.diff generated from svn
  svn diff -r r250:r260
* Thu May  7 2015 hrvoje.senjan@gmail.com
- Comment out the Source URL, since we now have a git snapshot
* Fri Feb  6 2015 dev@dominik-schmidt.de
- update to latest svn trunk
  * fixes coninstallation of Qt4 and Qt5 devel packages
  * remove patch soversion.diff, it was a downstream hack
  * upstream uses a new soname now
* Sun Dec 28 2014 alinm.elena@gmail.com
- this is qt5 version splitted from the qt4 one.
* Sat Oct 11 2014 crrodriguez@opensuse.org
- quazip-devel should require pkgconfig(qtcore)
- Build shared library with -fvisibility-inlines-hidden
- Ensure doxygen does not create html files with timestamps.
* Sat Sep  7 2013 stefan@fam-elser.de
- Update to 0.5.1 version:
  * Lots of QuaZipDir fixes, thanks to all bug reporters.
  * Full Qt Creator support.
  * MS VS 2010 Express support.
  * Qt5 support (didn't need any source code changes anyway).
  * Lots of minor bug fixes.
* Sat Dec 15 2012 p.drouand@gmail.com
- Update to 0.5 version:
  * Added run_moc.bat files for building under Windows in case Qt
    integration is not available (e. g. VS 2008 Express).
  * Added the QuaZipDir class to simplify ZIP navigation in terms
    of directories.
  * Added the QuaGzipFile class for working with GZIP archives. It
    was added as a bonus since it has nothing to do with the main
    purpose of the library. It probably won't get any major
    improvements, although minor bug fixes are possible.
  * Added the QuaZIODevice class for working with zlib
    compression. It has nothing to do with the ZIP format, and
    therefore the same notice as for the QuaGzipFile applies.
  * The global comment is no longer erased when adding files to
    an archive.
  * Many bug fixes.
* Sun Jan 29 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
* Mon Sep 12 2011 adam@mizerski.pl
- update to 0.4.3
  See NEWS for details
* Wed Sep  7 2011 adam@mizerski.pl
- update to 0.4.2
  See NEWS for details
* Fri May 27 2011 cfarrell@novell.com
- license update: GPL-2.0+ or LGPL-2.1+
  Update license syntax. Also GPLv2 was not correct. It is an ^or later^
  clause
* Wed Feb 23 2011 adam@mizerski.pl
- new package
